# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/subaccounts/perpetual_position.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dydxprotocol/subaccounts/perpetual_position.proto\x12\x18\x64ydxprotocol.subaccounts\x1a\x14gogoproto/gogo.proto\"\xc7\x02\n\x11PerpetualPosition\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12Z\n\x08quantums\x18\x02 \x01(\x0c\x42H\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\xc8\xde\x1f\x00\x12_\n\rfunding_index\x18\x03 \x01(\x0c\x42H\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\xc8\xde\x1f\x00\x12_\n\rquote_balance\x18\x04 \x01(\x0c\x42H\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\xc8\xde\x1f\x00\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.perpetual_position_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _PERPETUALPOSITION.fields_by_name['quantums']._options = None
  _PERPETUALPOSITION.fields_by_name['quantums']._serialized_options = b'\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\310\336\037\000'
  _PERPETUALPOSITION.fields_by_name['funding_index']._options = None
  _PERPETUALPOSITION.fields_by_name['funding_index']._serialized_options = b'\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\310\336\037\000'
  _PERPETUALPOSITION.fields_by_name['quote_balance']._options = None
  _PERPETUALPOSITION.fields_by_name['quote_balance']._serialized_options = b'\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\310\336\037\000'
  _PERPETUALPOSITION._serialized_start=102
  _PERPETUALPOSITION._serialized_end=429
# @@protoc_insertion_point(module_scope)
